@@ -4,13 +4,13 @@ import pytest
 
 
 class TestTrainLogger:
-    """Test suite for TrainLogger."""
+    """Test suite for BaseTrainLogger."""
     
     def test_train_logger_initialization(self):
-        """Test TrainLogger can be initialized."""
-        from dfm_python.logger.train_logger import TrainLogger
+        """Test BaseTrainLogger can be initialized."""
+        from dfm_python.logger.train_logger import BaseTrainLogger
         
-        logger = TrainLogger(model_name="TestModel", verbose=True)
+        logger = BaseTrainLogger(model_name="TestModel", verbose=True)
         assert logger.model_name == "TestModel"
         assert logger.verbose is True
         assert hasattr(logger, 'iterations')
