@@ -33,4 +33,11 @@ class TestConfigurationError:
         """Test ConfigurationError can be raised."""
         with pytest.raises(ConfigurationError):
             raise ConfigurationError("Configuration error")
+    
+    def test_configuration_error_with_details(self):
+        """Test ConfigurationError with details parameter."""
+        with pytest.raises(ConfigurationError) as exc_info:
+            raise ConfigurationError("Main error", details="Additional details")
+        assert "Main error" in str(exc_info.value)
+        assert exc_info.value.details == "Additional details"
 
